@@ -13,7 +13,8 @@ def get_hash(config_unit: ConfigUnit) -> str:
 
 def _get_computed_hash(config_unit: ConfigUnit) -> str:
     hash_input = \
-        dirhash(config_unit.directory, 'sha1', ignore=[".*", ".*/"])
+        dirhash(config_unit.directory, 'sha1',
+                ignore=['.git', '.git/', '.drkns-persistence/'])
 
     for dependency_config_unit in config_unit.dependencies.values():
         hash_input += _get_computed_hash(dependency_config_unit)
