@@ -1,13 +1,25 @@
 
+class UnknownDependencyException(Exception):
+    pass
+
+
 class UnknownStepException(Exception):
     pass
 
 
-class MissingCommandException(Exception):
+class UnknownCommandException(Exception):
     pass
 
 
-class UnknownCommandException(Exception):
+class UnknownCommandFlagException(Exception):
+    pass
+
+
+class CircularDependencyException(Exception):
+    pass
+
+
+class MissingCommandException(Exception):
     pass
 
 
